@@ -1172,7 +1172,6 @@ static struct pam_conv PAM_conversation = {
 
 static int pam_doit(void)
 {
-	char *user;
 	int error;
 
 	error = pam_authenticate(pamh, 0);
@@ -1192,6 +1191,8 @@ static int pam_doit(void)
 		return 1;
 	}
 	if (error == PAM_SUCCESS) {
+		const void *vp;
+
 		/* Alright, we got it */
 		error = pam_acct_mgmt(pamh, 0);
 		if (error == PAM_SUCCESS)
@@ -1199,8 +1200,10 @@ static int pam_doit(void)
 		if (error == PAM_SUCCESS)
 			error = pam_setcred(pamh, PAM_ESTABLISH_CRED);
 		if (error == PAM_SUCCESS)
-			error = pam_get_item(pamh, PAM_USER, (const void **) &user);
+			error = pam_get_item(pamh, PAM_USER, &vp);
 		if (error == PAM_SUCCESS) {
+			const char *user = vp;
+
 			if (strcmp(user, "ftp") == 0) {
 				guest = 1;
 			}
@@ -2083,7 +2086,7 @@ void statfilecmd(char *filename)
 	int c;
 	char line[LINE_MAX];
 
-	(void)snprintf(line, sizeof(line), "/bin/ls -lgA %s", filename);
+	(void)snprintf(line, sizeof(line), "/bin/ls -lA %s", filename);
 	fin = ftpd_popen(line, "r");
 	lreply(211, "status of %s:", filename);
 	while ((c = getc(fin)) != EOF) {
